import { BaseInputElement, OptionElement } from "./index";
/**
 * Represents a checkbox input element.
 */
export declare class CheckboxElement extends BaseInputElement<string[]> {
    /** The label of the input element. */
    private label;
    /** The default values to be selected in the checkbox. */
    private defaultValue?;
    /** The options available for the checkbox input element. */
    private options;
    /**
     * Creates a new instance of the CheckboxInput class.
     * @param elementId The ID of the input element.
     * @param label The label of the input element.
     * @param options The options available for the checkbox input element.
     */
    constructor(elementId: string, label: string, options?: OptionElement[]);
    /**
     * Gets the label of the input element.
     * @returns The label of the input element.
     */
    getLabel(): string;
    /**
     * Sets the default values to be selected in the checkbox.
     * @param defaultValue The default values to be selected in the checkbox.
     */
    setDefaultValue(defaultValue: string[]): void;
    /**
     * Gets the default values to be selected in the checkbox.
     * @returns The default values to be selected in the checkbox.
     * */
    getDefaultValue(): string[] | undefined;
    /**
     * Gets the options available for the checkbox input element.
     * @returns The options available for the checkbox input element.
     */
    getOptions(): OptionElement[];
    static fromJSON(json: any): CheckboxElement;
}
//# sourceMappingURL=CheckboxElement.d.ts.map