import { BaseInputElement, OptionElement } from "./index";
/**
 * Represents a dropdown input element.
 */
export declare class DropdownElement extends BaseInputElement<string> {
    /**
     * The label of the input element.
     */
    private label;
    /**
     * The default value to be selected in the dropdown.
     */
    private defaultValue?;
    /**
     * The options available for the dropdown input element.
     */
    private options;
    /**
     * Creates a new instance of DropdownInput.
     * @param elementId - The ID of the input element.
     * @param label - The label of the input element.
     * @param options - The options available for the dropdown input element.
     */
    constructor(elementId: string, label: string, options?: OptionElement[]);
    /**
     * Gets the label of the input element.
     * @returns The label of the input element.
     */
    getLabel(): string;
    /**
     * Gets the default value to be selected in the dropdown.
     * @returns The default value to be selected in the dropdown.
     */
    getDefaultValue(): string | undefined;
    /**
     * Sets the default value to be selected in the dropdown.
     * @param defaultValue - The default value to be selected in the dropdown.
     */
    setDefaultValue(defaultValue: string): void;
    /**
     * Gets the options available for the dropdown input element.
     * @returns The options available for the dropdown input element.
     */
    getOptions(): OptionElement[];
    static fromJSON(json: any): DropdownElement;
}
//# sourceMappingURL=DropdownElement.d.ts.map