import { BaseInputElement, OptionElement } from "./index";
/**
 * Represents a singleSelect button input element.
 */
export declare class SingleSelectElement extends BaseInputElement<string> {
    /** The label of the input element. */
    private label;
    /** The default value of the input element. */
    private defaultValue?;
    /** The options available for the singleSelect input element. */
    private options;
    /**
     * Creates a new instance of the SingleSelectElement class.
     * @param elementId The ID of the singleSelect button element.
     * @param label The label of the singleSelect button element.
     * @param options The options available for the singleSelect button element.
     */
    constructor(elementId: string, label: string, options?: OptionElement[]);
    /**
     * Gets the label of the input element.
     * @returns The label of the input element.
     */
    getLabel(): string;
    /**
     * Gets the default value of the input element.
     * @returns The default value of the input element.
     */
    getDefaultValue(): string | undefined;
    /**
     * Sets the default value of the input element.
     * @param defaultValue The default value of the input element.
     */
    setDefaultValue(defaultValue: string): void;
    /**
     * Gets the options available for the singleSelect input element.
     * @returns The options available for the singleSelect input element.
     */
    getOptions(): OptionElement[];
    static fromJSON(json: any): SingleSelectElement;
}
//# sourceMappingURL=SingleSelectElement.d.ts.map