import { BaseInputElement } from "./index";
/**
 * Represents a text input element.
 */
export declare class TextInputElement extends BaseInputElement<string> {
    /** The label of the input element. */
    private label;
    /** The maximum number of lines for a multi-line text input element. */
    private maxLines?;
    /** The placeholder text to display in the input element. */
    private placeholder?;
    /**
     * The default value in text input.
     */
    private defaultValue?;
    /**
     * Creates a new instance of the TextInputElement class.
     * @param {string} elementId - The unique identifier of the form element.
     * @param {string} label - The label of the input element.
     */
    constructor(elementId: string, label: string);
    /**
     * Returns the label of the input element.
     * @returns {string} The label of the input element.
     */
    getLabel(): string;
    /**
     * Returns the maximum number of lines for a multi-line text input element.
     * @returns {number} The maximum number of lines for a multi-line text input element.
     */
    getMaxLines(): number | undefined;
    /**
     * Sets the maximum number of lines for a multi-line text input element.
     * @param {number} maxLines - The maximum number of lines for a multi-line text input element.
     */
    setMaxLines(maxLines: number): void;
    /**
     * Returns the placeholder text to display in the input element.
     * @returns {string} The placeholder text to display in the input element.
     */
    getPlaceholder(): string | undefined;
    /**
     * Sets the placeholder text to display in the input element.
     * @param {string} placeholder - The placeholder text to display in the input element.
     */
    setPlaceholder(placeholder: string): void;
    /**
     * Returns the default value in text input.
     * @returns {string} The default value in text input.
     */
    getDefaultValue(): string | undefined;
    /**
     * Sets the default value in text input.
     * @param {string} defaultValue - The default value in text input.
     * @returns {string} The default value in text input.
     */
    setDefaultValue(defaultValue: string): void;
    static fromJSON(json: any): TextInputElement;
}
//# sourceMappingURL=TextInputElement.d.ts.map